<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN" sourcelanguage="en_US">
<context>
    <name>AddFxContextMenu</name>
    <message>
        <source>Insert FX</source>
        <translation>插入特效</translation>
    </message>
    <message>
        <source>Add FX</source>
        <translation>添加特效</translation>
    </message>
    <message>
        <source>Replace FX</source>
        <translation>替换特效</translation>
    </message>
    <message>
        <source>Insert </source>
        <translation>插入 </translation>
    </message>
    <message>
        <source>Add </source>
        <translation>添加 </translation>
    </message>
    <message>
        <source>Replace </source>
        <translation>替换 </translation>
    </message>
</context>
<context>
    <name>AddWordButton</name>
    <message>
        <source>Character</source>
        <translation>字符</translation>
    </message>
    <message>
        <source>Part</source>
        <translation>部分</translation>
    </message>
    <message>
        <source>Suffix</source>
        <translation>后缀</translation>
    </message>
    <message>
        <source>New</source>
        <translation>新建</translation>
    </message>
    <message>
        <source>Add New Word for %1</source>
        <translation>添加新词到 %1</translation>
    </message>
</context>
<context>
    <name>AdjustPaletteDialog</name>
    <message>
        <source>Adjust Current Level to This Palette</source>
        <translation>调整当前层级到此调色板</translation>
    </message>
    <message>
        <source>Tolerance</source>
        <translation>容差</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>应用</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>CameraPainter</name>
    <message>
        <source>&amp;Reset Center</source>
        <translation>重置中心点(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Activate</source>
        <translation>启用(&amp;A)</translation>
    </message>
</context>
<context>
    <name>CameraSettingsWidget</name>
    <message>
        <source>Width:</source>
        <translation type="vanished">宽度:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation type="vanished">高度:</translation>
    </message>
    <message>
        <source>XPx:</source>
        <translation type="vanished">XPx:</translation>
    </message>
    <message>
        <source>XDpi:</source>
        <translation type="vanished">XDpi:</translation>
    </message>
    <message>
        <source>YDpi:</source>
        <translation type="vanished">YDpi:</translation>
    </message>
    <message>
        <source>Use Current Level Settings</source>
        <translation>使用当前层级设置</translation>
    </message>
    <message>
        <source>Bad camera preset</source>
        <translation>不正确的摄影机预设</translation>
    </message>
    <message>
        <source>Preset name</source>
        <translation>预设名称</translation>
    </message>
    <message>
        <source>Enter the name for %1</source>
        <translation>请给 %1 命名</translation>
    </message>
    <message>
        <source>YPx:</source>
        <translation type="vanished">YPx:</translation>
    </message>
    <message>
        <source>AR:</source>
        <translation type="vanished">AR:</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Force Squared Pixel</source>
        <translation>强制正方形像素</translation>
    </message>
    <message>
        <source>Error : Preset Name is Invalid</source>
        <translation>错误: 预设名称无效</translation>
    </message>
    <message>
        <source>The preset name must not use &apos;,&apos;(comma).</source>
        <translation>不能在预设名称中使用 &quot;,&quot; (逗号)。</translation>
    </message>
    <message>
        <source>DPI</source>
        <translation>DPI</translation>
    </message>
    <message>
        <source>Pixels</source>
        <translation>像素</translation>
    </message>
    <message>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <source>&apos;%1&apos; doesn&apos;t seem a well formed camera preset.
Possibly the preset file has been corrupted</source>
        <translation type="vanished">“%1”不像是正确格式的摄影机预设。
预设文件可能已经损坏了</translation>
    </message>
    <message>
        <source>&apos;%1&apos; doesn&apos;t seem a well formed camera preset. 
Possibly the preset file has been corrupted</source>
        <translation>%1&apos; 不是格式完好的摄影机预设。
可能预设文件已经被损坏了</translation>
    </message>
    <message>
        <source>A/R</source>
        <translation>A/R</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation>&lt;定制&gt;</translation>
    </message>
    <message>
        <source>cm</source>
        <translation>厘米</translation>
    </message>
    <message>
        <source>mm</source>
        <translation>毫米</translation>
    </message>
    <message>
        <source>inch</source>
        <translation>英尺</translation>
    </message>
    <message>
        <source>field</source>
        <translation>视场</translation>
    </message>
    <message>
        <source>pixel</source>
        <translation>像素</translation>
    </message>
</context>
<context>
    <name>ChannelHisto</name>
    <message>
        <source>Red</source>
        <translation>红</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>绿</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>蓝</translation>
    </message>
    <message>
        <source>Alpha</source>
        <translation>透明度</translation>
    </message>
    <message>
        <source>RGBA</source>
        <translation type="vanished">RGBA</translation>
    </message>
    <message>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
</context>
<context>
    <name>CleanupCameraSettingsWidget</name>
    <message>
        <source>Closest:</source>
        <translation type="vanished">最靠近的:</translation>
    </message>
    <message>
        <source>X:</source>
        <translation type="vanished">左右:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation type="vanished">上下:</translation>
    </message>
    <message>
        <source>DPI:</source>
        <translation type="vanished">DPI:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="vanished">名称:</translation>
    </message>
    <message>
        <source>Path:</source>
        <translation type="vanished">路径:</translation>
    </message>
    <message>
        <source>Field settings</source>
        <translation type="vanished">规格设置</translation>
    </message>
    <message>
        <source>XPx:</source>
        <translation type="vanished">XPx:</translation>
    </message>
    <message>
        <source>YPx:</source>
        <translation type="vanished">YPx:</translation>
    </message>
    <message>
        <source>Resulting Level Info</source>
        <translation type="vanished">结果层级信息</translation>
    </message>
    <message>
        <source>Y</source>
        <translation>上下</translation>
    </message>
    <message>
        <source>X</source>
        <translation>左右</translation>
    </message>
</context>
<context>
    <name>ColumnPainter</name>
    <message>
        <source>&amp;Reset Center</source>
        <translation>重置中心点(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Open Subxsheet</source>
        <translation type="vanished">打开子摄影表(&amp;O)</translation>
    </message>
</context>
<context>
    <name>ComboHistoRGBLabel</name>
    <message>
        <source>R:%1 G:%2 B:%3</source>
        <translation>R:%1 G:%2 B:%3</translation>
    </message>
</context>
<context>
    <name>ComboHistogram</name>
    <message>
        <source>Picked Color</source>
        <translation>拾取的颜色</translation>
    </message>
    <message>
        <source>Average Color (Ctrl + Drag)</source>
        <translation>平均色(Ctrl + 拖拽)</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>8bit (0-255)</source>
        <translation>8位 (0-255)</translation>
    </message>
    <message>
        <source>16bit (0-65535)</source>
        <translation>16位 (0-65535)</translation>
    </message>
    <message>
        <source>0.0-1.0</source>
        <translation>0.0-1.0</translation>
    </message>
</context>
<context>
    <name>DVGui</name>
    <message>
        <source>OK</source>
        <translation type="vanished">确定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">取消</translation>
    </message>
</context>
<context>
    <name>DVGui::CleanupColorField</name>
    <message>
        <source>Brightness:</source>
        <translation>亮度:</translation>
    </message>
    <message>
        <source>Contrast:</source>
        <translation>对比度:</translation>
    </message>
    <message>
        <source>Color Threshold</source>
        <translation type="vanished">颜色阈值</translation>
    </message>
    <message>
        <source>White Threshold</source>
        <translation type="vanished">白场阈值</translation>
    </message>
    <message>
        <source>H Range</source>
        <translation>色相范围</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>线宽</translation>
    </message>
    <message>
        <source>Color Thres</source>
        <translation>颜色阈值</translation>
    </message>
    <message>
        <source>White Thres</source>
        <translation>白场阈值</translation>
    </message>
</context>
<context>
    <name>DVGui::ColorField</name>
    <message>
        <source>R:</source>
        <translation>R:</translation>
    </message>
    <message>
        <source>G:</source>
        <translation>G:</translation>
    </message>
    <message>
        <source>B:</source>
        <translation>B:</translation>
    </message>
    <message>
        <source>A:</source>
        <translation>A:</translation>
    </message>
    <message>
        <source>Paste Color</source>
        <translation>粘贴颜色</translation>
    </message>
    <message>
        <source>Paste Color of %1</source>
        <translation>粘贴%1的颜色</translation>
    </message>
    <message>
        <source>Copy Color</source>
        <translation>复制颜色</translation>
    </message>
</context>
<context>
    <name>DVGui::DvTextEdit</name>
    <message>
        <source>Bold</source>
        <translation>粗体</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>斜体</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>下划线</translation>
    </message>
    <message>
        <source>Align Left</source>
        <translation>左对齐</translation>
    </message>
    <message>
        <source>Align Center</source>
        <translation>居中对齐</translation>
    </message>
    <message>
        <source>Align Right</source>
        <translation>右对齐</translation>
    </message>
</context>
<context>
    <name>DVGui::FileField</name>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
<context>
    <name>DVGui::HexColorNamesEditor</name>
    <message>
        <source>Hex Color Names Editor</source>
        <translation>16进制颜色名编辑器</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>应用</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>不选择</translation>
    </message>
    <message>
        <source>Add Color</source>
        <translation>添加颜色</translation>
    </message>
    <message>
        <source>Delete Color</source>
        <translation>删除颜色</translation>
    </message>
    <message>
        <source>User Defined Colors</source>
        <translation>用户定义颜色</translation>
    </message>
    <message>
        <source>Default Main Colors</source>
        <translation>默认主颜色</translation>
    </message>
    <message>
        <source>Enable Auto-Complete</source>
        <translation>启用自动完成</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>导入</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>导出</translation>
    </message>
    <message>
        <source>Open Color Names</source>
        <translation>打开颜色名</translation>
    </message>
    <message>
        <source>Text or XML (*.txt *.xml);;Text files (*.txt);;XML files (*.xml)</source>
        <translation>文本或者  XML (*.txt *.xml);;文本文件 (*.txt);;XML 文件 (*.xml)</translation>
    </message>
    <message>
        <source>Hex Color Names Import</source>
        <translation>16进制颜色名导入</translation>
    </message>
    <message>
        <source>Do you want to merge with existing entries?</source>
        <translation>你要与现有条目合并吗？</translation>
    </message>
    <message>
        <source>Error importing color names XML</source>
        <translation>导入颜色名错误 XML</translation>
    </message>
    <message>
        <source>Save Color Names</source>
        <translation>保存颜色名</translation>
    </message>
    <message>
        <source>XML files (*.xml);;Text files (*.txt)</source>
        <translation>XML 文件 (*.xml);;文本文件 (*.txt)</translation>
    </message>
    <message>
        <source>Error exporting color names XML</source>
        <translation>导出颜色名错误 XML</translation>
    </message>
</context>
<context>
    <name>DVGui::LineEdit</name>
    <message>
        <source>A file name cannot contains any of the following chracters: /\:*?&quot;&lt;&gt;|.</source>
        <translation type="vanished">文件名不能包含如下的任一字符: /\:*?&quot;&lt;&gt;|.</translation>
    </message>
    <message>
        <source>A file name cannot contains any of the following characters: /\:*?&quot;&lt;&gt;|.</source>
        <translation>文件名不能包含如下的任一字符: /\:*?&quot;&lt;&gt;|.</translation>
    </message>
</context>
<context>
    <name>DVGui::ProgressDialog</name>
    <message>
        <source>Toonz</source>
        <translation type="vanished">OpenToonz</translation>
    </message>
    <message>
        <source>OpenToonz</source>
        <translation>OpenToonz</translation>
    </message>
</context>
<context>
    <name>DVGui::RadioButtonDialog</name>
    <message>
        <source>Toonz</source>
        <translation type="vanished">OpenToonz</translation>
    </message>
    <message>
        <source>OpenToonz</source>
        <translation>OpenToonz</translation>
    </message>
</context>
<context>
    <name>DVGui::StyleIndexLineEdit</name>
    <message>
        <source>current</source>
        <translation>当前</translation>
    </message>
</context>
<context>
    <name>DVGui::ToneCurveField</name>
    <message>
        <source>Channel:</source>
        <translation>通道:</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>范围:</translation>
    </message>
    <message>
        <source>Output:</source>
        <translation>输出:</translation>
    </message>
    <message>
        <source>Input:</source>
        <translation>输入:</translation>
    </message>
</context>
<context>
    <name>DVGui::ValidatedChoiceDialog</name>
    <message>
        <source>Apply</source>
        <translation>应用</translation>
    </message>
    <message>
        <source>Apply to All</source>
        <translation>全部应用</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>DvTextEdit</name>
    <message>
        <source>Bold</source>
        <translation type="vanished">粗体</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="vanished">斜体</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation type="vanished">下划线</translation>
    </message>
    <message>
        <source>Align Left</source>
        <translation type="vanished">左对齐</translation>
    </message>
    <message>
        <source>Align Center</source>
        <translation type="vanished">居中对齐</translation>
    </message>
    <message>
        <source>Align Right</source>
        <translation type="vanished">右对齐</translation>
    </message>
</context>
<context>
    <name>EaseInOutSegmentPage</name>
    <message>
        <source>Ease In:</source>
        <translation>缓入:</translation>
    </message>
    <message>
        <source>Ease Out:</source>
        <translation>缓出:</translation>
    </message>
</context>
<context>
    <name>EasyInputArea</name>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>%1 is already registered</source>
        <translation>%1 已经被注册了</translation>
    </message>
</context>
<context>
    <name>FileField</name>
    <message>
        <source>...</source>
        <translation type="vanished">...</translation>
    </message>
</context>
<context>
    <name>FileSegmentPage</name>
    <message>
        <source>File Path:</source>
        <translation>文件路径:</translation>
    </message>
    <message>
        <source>Column:</source>
        <translation>列:</translation>
    </message>
    <message>
        <source>Unit:</source>
        <translation>单位:</translation>
    </message>
</context>
<context>
    <name>FlipConsole</name>
    <message>
        <source> FPS </source>
        <translation> FPS </translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>快照</translation>
    </message>
    <message>
        <source>Define Sub-camera</source>
        <translation>定义子摄影机</translation>
    </message>
    <message>
        <source>Background Colors</source>
        <translation>背景色</translation>
    </message>
    <message>
        <source>Framerate</source>
        <translation>帧速率</translation>
    </message>
    <message>
        <source>Playback Controls</source>
        <translation>回放控制</translation>
    </message>
    <message>
        <source>Color Channels</source>
        <translation>颜色通道</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>设置关键帧</translation>
    </message>
    <message>
        <source>Histogram</source>
        <translation>直方图</translation>
    </message>
    <message>
        <source>&amp;Save Images</source>
        <translation>保存图像(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Snapshot</source>
        <translation>快照(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Compare to Snapshot</source>
        <translation>和快照比较(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Define Sub-camera</source>
        <translation>定义子摄影机(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;White Background</source>
        <translation>白背景(&amp;W)</translation>
    </message>
    <message>
        <source>&amp;Black Background</source>
        <translation>黑背景(&amp;B)</translation>
    </message>
    <message>
        <source>&amp;Checkered Background</source>
        <translation>棋盘格背景(&amp;C)</translation>
    </message>
    <message>
        <source>Set the playback frame rate</source>
        <translation>设置回放帧速率</translation>
    </message>
    <message>
        <source>&amp;First Frame</source>
        <translation>第一帧(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Previous Frame</source>
        <translation>上一帧(&amp;P)</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Loop</source>
        <translation>循环</translation>
    </message>
    <message>
        <source>&amp;Next frame</source>
        <translation type="vanished">下一帧(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Last Frame</source>
        <translation>最后一帧(&amp;L)</translation>
    </message>
    <message>
        <source>Red Channel</source>
        <translation>红通道</translation>
    </message>
    <message>
        <source>Red Channel in Grayscale</source>
        <translation>红通道(灰阶)</translation>
    </message>
    <message>
        <source>Green Channel</source>
        <translation>绿通道</translation>
    </message>
    <message>
        <source>Green Channel in Grayscale</source>
        <translation>绿通道(灰阶)</translation>
    </message>
    <message>
        <source>Blue Channel</source>
        <translation>蓝通道</translation>
    </message>
    <message>
        <source>Blue Channel in Grayscale</source>
        <translation>蓝通道(灰阶)</translation>
    </message>
    <message>
        <source>Alpha Channel</source>
        <translation>Alpha 通道</translation>
    </message>
    <message>
        <source>&amp;Soundtrack </source>
        <translation>声轨(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Histogram</source>
        <translation>直方图(&amp;H)</translation>
    </message>
    <message>
        <source> FPS	</source>
        <translation> FPS	</translation>
    </message>
    <message>
        <source> Frame  </source>
        <translation type="vanished">帧</translation>
    </message>
    <message>
        <source>Set the current frame</source>
        <translation>设置当前帧</translation>
    </message>
    <message>
        <source>Drag to play the animation</source>
        <translation>[拖动]播放动画</translation>
    </message>
    <message>
        <source>Define Loading Box</source>
        <translation>定义加载框</translation>
    </message>
    <message>
        <source>Use Loading Box</source>
        <translation>使用加载框</translation>
    </message>
    <message>
        <source>&amp;Define Loading Box</source>
        <translation>定义加载框(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Use Loading Box</source>
        <translation>使用加载框(&amp;U)</translation>
    </message>
    <message>
        <source>Display Areas as Filled</source>
        <translation>将区域显示为已填充</translation>
    </message>
    <message>
        <source>&amp;Display Areas as Filled</source>
        <translation>将区域显示为已填充(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Locator</source>
        <translation>定位器(&amp;L)</translation>
    </message>
    <message>
        <source>Viewer Controls</source>
        <translation>查看器控件</translation>
    </message>
    <message>
        <source>&amp;Zoom In</source>
        <translation>放大(&amp;Z)</translation>
    </message>
    <message>
        <source>&amp;Zoom Out</source>
        <translation>缩小(&amp;Z)</translation>
    </message>
    <message>
        <source>&amp;Flip Horizontally</source>
        <translation>水平翻转(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Flip Vertically</source>
        <translation>垂直翻转(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Reset View</source>
        <translation>重置视图(&amp;R)</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>声音</translation>
    </message>
    <message>
        <source>Locator</source>
        <translation>定位器</translation>
    </message>
    <message>
        <source>&amp;Next Frame</source>
        <translation>下一帧(&amp;N)</translation>
    </message>
</context>
<context>
    <name>FontParamField</name>
    <message>
        <source>Style:</source>
        <translation>样式:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>大小:</translation>
    </message>
</context>
<context>
    <name>FrameNavigator</name>
    <message>
        <source>Previous Frame</source>
        <translation>上一帧</translation>
    </message>
    <message>
        <source>Next Frame</source>
        <translation>下一帧</translation>
    </message>
</context>
<context>
    <name>FunctionExpressionSegmentPage</name>
    <message>
        <source>Expression:</source>
        <translation>表达式:</translation>
    </message>
    <message>
        <source>Unit:</source>
        <translation>单位:</translation>
    </message>
    <message>
        <source>There is a circular reference in the definition of the interpolation.</source>
        <translation>插值定义中存在循环引用。</translation>
    </message>
</context>
<context>
    <name>FunctionPanel</name>
    <message>
        <source>Link Handles</source>
        <translation>链接手柄</translation>
    </message>
    <message>
        <source>Unlink Handles</source>
        <translation>断开链接手柄</translation>
    </message>
    <message>
        <source>Reset Handles</source>
        <translation>重置手柄</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>设置关键帧</translation>
    </message>
    <message>
        <source>Activate Cycle</source>
        <translation>启用循环</translation>
    </message>
    <message>
        <source>Deactivate Cycle</source>
        <translation>禁用循环</translation>
    </message>
    <message>
        <source>Linear Interpolation</source>
        <translation>线性插值</translation>
    </message>
    <message>
        <source>Speed In / Speed Out Interpolation</source>
        <translation>速入/速出插值</translation>
    </message>
    <message>
        <source>Ease In / Ease Out Interpolation</source>
        <translation>缓入/缓出插值</translation>
    </message>
    <message>
        <source>Ease In / Ease Out (%) Interpolation</source>
        <translation>缓入/缓出(%)插值</translation>
    </message>
    <message>
        <source>Exponential Interpolation</source>
        <translation>指数运算插值</translation>
    </message>
    <message>
        <source>Expression Interpolation</source>
        <translation>表达式插值</translation>
    </message>
    <message>
        <source>File Interpolation</source>
        <translation>文件插值</translation>
    </message>
    <message>
        <source>Constant Interpolation</source>
        <translation>恒定插值</translation>
    </message>
    <message>
        <source>Fit Selection</source>
        <translation>适合选区</translation>
    </message>
    <message>
        <source>Fit</source>
        <translation>适合</translation>
    </message>
    <message>
        <source>Similar Shape Interpolation</source>
        <translation>相似形状插值</translation>
    </message>
    <message>
        <source>Step 1</source>
        <translation>步长为 1</translation>
    </message>
    <message>
        <source>Step 2</source>
        <translation>步长为 2</translation>
    </message>
    <message>
        <source>Step 3</source>
        <translation>步长为 3</translation>
    </message>
    <message>
        <source>Step 4</source>
        <translation>步长为 4</translation>
    </message>
    <message>
        <source>Function Curves</source>
        <translation>功能曲线</translation>
    </message>
    <message>
        <source>Smooth</source>
        <translation>平滑</translation>
    </message>
    <message>
        <source>Frame Based</source>
        <translation>基于帧</translation>
    </message>
    <message>
        <source>Curve Shape</source>
        <translation>曲线形状</translation>
    </message>
</context>
<context>
    <name>FunctionSegmentViewer</name>
    <message>
        <source>Linear</source>
        <translation>线性</translation>
    </message>
    <message>
        <source>Speed In / Speed Out</source>
        <translation>速入/速出</translation>
    </message>
    <message>
        <source>Ease In / Ease Out</source>
        <translation>缓入/缓出</translation>
    </message>
    <message>
        <source>Ease In / Ease Out %</source>
        <translation>缓入/缓出(%)</translation>
    </message>
    <message>
        <source>Exponential</source>
        <translation>指数运算</translation>
    </message>
    <message>
        <source>Expression</source>
        <translation>表达式</translation>
    </message>
    <message>
        <source>File</source>
        <translation>文件</translation>
    </message>
    <message>
        <source>Constant</source>
        <translation>恒定</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation type="vanished">范围:</translation>
    </message>
    <message>
        <source>Interpolation:</source>
        <translation>插值:</translation>
    </message>
    <message>
        <source>Step:</source>
        <translation type="vanished">步长:</translation>
    </message>
    <message>
        <source>Similar Shape</source>
        <translation>相似形状</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>应用</translation>
    </message>
    <message>
        <source>&lt; </source>
        <translation>&lt; </translation>
    </message>
    <message>
        <source> &gt;</source>
        <translation> &gt;</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>加速</translation>
    </message>
    <message>
        <source>Ease</source>
        <translation>缓动</translation>
    </message>
    <message>
        <source>Ease%</source>
        <translation>缓动%</translation>
    </message>
    <message>
        <source>Expo</source>
        <translation>指数</translation>
    </message>
    <message>
        <source>Expr</source>
        <translation>表达式</translation>
    </message>
    <message>
        <source>Const</source>
        <translation>恒定</translation>
    </message>
    <message>
        <source>Similar</source>
        <translation>相似</translation>
    </message>
    <message>
        <source>????</source>
        <translation>????</translation>
    </message>
    <message>
        <source>From</source>
        <translation>起点</translation>
    </message>
    <message>
        <source>To</source>
        <translation>终点</translation>
    </message>
    <message>
        <source>Step</source>
        <translation>步长</translation>
    </message>
    <message>
        <source>Link/Unlink Handles</source>
        <translation>链接/断开手柄</translation>
    </message>
</context>
<context>
    <name>FunctionSelection</name>
    <message>
        <source>There is a circular reference in the definition of the interpolation.</source>
        <translation>该插值定义中存在循环引用。</translation>
    </message>
</context>
<context>
    <name>FunctionSheet</name>
    <message>
        <source>Function Editor</source>
        <translation>功能编辑器</translation>
    </message>
</context>
<context>
    <name>FunctionSheetButtonArea</name>
    <message>
        <source>Toggle synchronizing zoom with xsheet</source>
        <translation>启用/停用与摄影表同步</translation>
    </message>
</context>
<context>
    <name>FunctionSheetCellViewer</name>
    <message>
        <source>Delete Key</source>
        <translation>删除关键帧</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>设置关键帧</translation>
    </message>
    <message>
        <source>Linear Interpolation</source>
        <translation>线性插值</translation>
    </message>
    <message>
        <source>Speed In / Speed Out Interpolation</source>
        <translation>速入/速出插值</translation>
    </message>
    <message>
        <source>Ease In / Ease Out Interpolation</source>
        <translation>缓入/缓出插值</translation>
    </message>
    <message>
        <source>Ease In / Ease Out (%) Interpolation</source>
        <translation>缓入/缓出(%)插值</translation>
    </message>
    <message>
        <source>Expression Interpolation</source>
        <translation>表达式插值</translation>
    </message>
    <message>
        <source>File Interpolation</source>
        <translation>文件插值</translation>
    </message>
    <message>
        <source>Constant Interpolation</source>
        <translation>恒定插值</translation>
    </message>
    <message>
        <source>Exponential Interpolation</source>
        <translation>指数运算插值</translation>
    </message>
    <message>
        <source>Step 1</source>
        <translation type="vanished">第 1 步</translation>
    </message>
    <message>
        <source>Step 2</source>
        <translation type="vanished">第 2 步</translation>
    </message>
    <message>
        <source>Step 3</source>
        <translation type="vanished">第 3 步</translation>
    </message>
    <message>
        <source>Step 4</source>
        <translation type="vanished">第 4 步</translation>
    </message>
    <message>
        <source>Activate Cycle</source>
        <translation>启用循环</translation>
    </message>
    <message>
        <source>Deactivate Cycle</source>
        <translation>禁用循环</translation>
    </message>
    <message>
        <source>Show Inbetween Values</source>
        <translation>显示过渡帧的值</translation>
    </message>
    <message>
        <source>Hide Inbetween Values</source>
        <translation>隐藏过渡帧的值</translation>
    </message>
    <message>
        <source>Change Interpolation</source>
        <translation>更改插值方式</translation>
    </message>
    <message>
        <source>Change Step</source>
        <translation>改变步长</translation>
    </message>
    <message>
        <source>Similar Shape Interpolation</source>
        <translation>相似形状插值</translation>
    </message>
</context>
<context>
    <name>FunctionSheetColumnHeadViewer</name>
    <message>
        <source>Some key(s) in this parameter loses original reference in expression.
Manually changing any keyframe will clear the warning.</source>
        <translation>在表达式中此参数的某些关键帧丢失原引用。
手工更改任意的关键帧将清理该警告。</translation>
    </message>
</context>
<context>
    <name>FunctionToolbar</name>
    <message>
        <source>Value</source>
        <translation>值</translation>
    </message>
    <message>
        <source>&amp;Function Editor Toggle</source>
        <translation type="vanished">切换功能编辑器(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Open Function Curve Editor</source>
        <translation>打开功能曲线编辑器(&amp;O)</translation>
    </message>
</context>
<context>
    <name>FunctionTreeModel</name>
    <message>
        <source>Stage</source>
        <translation>舞台</translation>
    </message>
    <message>
        <source>FX</source>
        <translation>特效</translation>
    </message>
    <message>
        <source>Plastic Skeleton</source>
        <translation>塑料骨架</translation>
    </message>
    <message>
        <source>Some key(s) in this parameter loses original reference in expression.
Manually changing any keyframe will clear the warning.</source>
        <translation>在表达式中此参数的某些关键帧丢失原引用。
手工更改任意的关键帧将清理该警告。</translation>
    </message>
</context>
<context>
    <name>FunctionTreeView</name>
    <message>
        <source>Save Curve</source>
        <translation>保存曲线</translation>
    </message>
    <message>
        <source>Load Curve</source>
        <translation>加载曲线</translation>
    </message>
    <message>
        <source>Export Data</source>
        <translation>导出数据</translation>
    </message>
    <message>
        <source>Show Animated Only</source>
        <translation>仅显示已动画的</translation>
    </message>
    <message>
        <source>Show All</source>
        <translation>显示全部</translation>
    </message>
    <message>
        <source>Table</source>
        <translation>动画台</translation>
    </message>
    <message>
        <source>Hide Selected</source>
        <translation>隐藏被选中的</translation>
    </message>
</context>
<context>
    <name>FxColumnPainter</name>
    <message>
        <source>&amp;Disconnect from Xsheet</source>
        <translation>断开摄影表的连接(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Connect to Xsheet</source>
        <translation>连接到摄影表(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Paste Add</source>
        <translation>粘贴添加(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>预览(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Open Subxsheet</source>
        <translation type="vanished">打开子摄影表(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Uncache Fx</source>
        <translation>取消特效缓存(&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Cache FX</source>
        <translation>缓存特效(&amp;C)</translation>
    </message>
</context>
<context>
    <name>FxOutputPainter</name>
    <message>
        <source>&amp;Delete</source>
        <translation>删除(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Activate</source>
        <translation>启用(&amp;A)</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>输出</translation>
    </message>
    <message>
        <source>Out</source>
        <translation type="vanished">Out</translation>
    </message>
</context>
<context>
    <name>FxPainter</name>
    <message>
        <source>&amp;Open Group</source>
        <translation>打开组(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Paste Replace</source>
        <translation>粘贴替换(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Paste Add</source>
        <translation>粘贴添加(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>删除(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Disconnect from Xsheet</source>
        <translation>断开摄影表的连接(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Connect to Xsheet</source>
        <translation>连接到摄影表(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Create Linked FX</source>
        <translation>创建已链接的特效(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Unlink</source>
        <translation>取消链接(&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Make Macro FX</source>
        <translation>制作宏特效(&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Explode Macro FX</source>
        <translation>展开宏特效(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Open Macro FX</source>
        <translation>打开宏特效(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Save As Preset...</source>
        <translation>另存为预设(&amp;S)...</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>预览(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Uncache FX</source>
        <translation>取消特效缓存(&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Cache FX</source>
        <translation>缓存特效(&amp;C)</translation>
    </message>
</context>
<context>
    <name>FxPalettePainter</name>
    <message>
        <source>&amp;Disconnect from Xsheet</source>
        <translation>断开摄影表的连接(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Connect to Xsheet</source>
        <translation>连接到摄影表(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>预览(&amp;P)</translation>
    </message>
</context>
<context>
    <name>FxPassThroughPainter</name>
    <message>
        <source>&amp;Paste Add</source>
        <translation>粘贴添加(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>预览(&amp;P)</translation>
    </message>
</context>
<context>
    <name>FxSchematicLink</name>
    <message>
        <source>&amp;Delete</source>
        <translation>删除(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Paste Insert</source>
        <translation>粘贴插入(&amp;P)</translation>
    </message>
</context>
<context>
    <name>FxSchematicOutputNode</name>
    <message>
        <source>Output</source>
        <translation>输出</translation>
    </message>
</context>
<context>
    <name>FxSchematicPassThroughNode</name>
    <message>
        <source> (Pass Through)</source>
        <translation> (通过)</translation>
    </message>
</context>
<context>
    <name>FxSchematicPort</name>
    <message>
        <source>&amp;Disconnect from Xsheet</source>
        <translation>断开摄影表的连接(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Connect to Xsheet</source>
        <translation>连接到摄影表(&amp;C)</translation>
    </message>
</context>
<context>
    <name>FxSchematicScene</name>
    <message>
        <source>Cannot Paste Insert a selection of unconnected FX nodes.
Select FX nodes and related links before copying or cutting the selection you want to paste.</source>
        <translation>无法“粘贴插入”多个未连接的特效节点。
请在拷贝或剪切选区之前，选择特效节点和它的关联链接。</translation>
    </message>
    <message>
        <source>Cannot Paste Add a selection of unconnected FX nodes.
Select FX nodes and related links before copying or cutting the selection you want to paste.</source>
        <translation>无法“粘贴添加”多个未连接的特效节点。
请在拷贝或剪切选区之前，选择特效节点和它的关联链接。</translation>
    </message>
    <message>
        <source>Cannot Paste Replace a selection of unconnected FX nodes.
Select FX nodes and related links before copying or cutting the selection you want to paste.</source>
        <translation>无法“粘贴替换”多个未连接的特效节点。
请在拷贝或剪切选区之前，选择特效节点和它的关联链接。</translation>
    </message>
</context>
<context>
    <name>FxSchematicXSheetNode</name>
    <message>
        <source>XSheet</source>
        <translation>摄影表</translation>
    </message>
</context>
<context>
    <name>FxSettings</name>
    <message>
        <source>&amp;Camera Preview</source>
        <translation>摄影机预览(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>预览(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;White Background</source>
        <translation>白背景(&amp;W)</translation>
    </message>
    <message>
        <source>&amp;Black Background</source>
        <translation>黑背景(&amp;B)</translation>
    </message>
    <message>
        <source>&amp;Checkered Background</source>
        <translation>棋盘格背景(&amp;C)</translation>
    </message>
    <message>
        <source> : </source>
        <translation> : </translation>
    </message>
    <message>
        <source>Fx Settings</source>
        <translation>特效设定</translation>
    </message>
</context>
<context>
    <name>FxXSheetPainter</name>
    <message>
        <source>&amp;Paste Add</source>
        <translation>粘贴添加(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>预览(&amp;P)</translation>
    </message>
    <message>
        <source>XSheet</source>
        <translation>摄影表</translation>
    </message>
    <message>
        <source>X</source>
        <translation type="vanished">X</translation>
    </message>
</context>
<context>
    <name>GroupPainter</name>
    <message>
        <source>&amp;Open Group</source>
        <translation>打开组(&amp;O)</translation>
    </message>
</context>
<context>
    <name>Histogram</name>
    <message>
        <source>Logarithmic Scale</source>
        <translation>对数刻度</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>值</translation>
    </message>
    <message>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>红</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>绿</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>蓝</translation>
    </message>
    <message>
        <source>Alpha</source>
        <translation>透明度</translation>
    </message>
</context>
<context>
    <name>InfoViewer</name>
    <message>
        <source>File Info</source>
        <translation>文件信息</translation>
    </message>
</context>
<context>
    <name>KeyframeNavigator</name>
    <message>
        <source>Previous Key</source>
        <translation>上一个关键帧</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>设置关键帧</translation>
    </message>
    <message>
        <source>Next Key</source>
        <translation>下一个关键帧</translation>
    </message>
</context>
<context>
    <name>LineEdit</name>
    <message>
        <source>A file name cannot contains any of the following chracters: /\:*?&quot;&lt;&gt;|.</source>
        <translation type="vanished">文件名能包含如下的任一字符: /\:*?&quot;&lt;&gt;|.</translation>
    </message>
</context>
<context>
    <name>MyPaintBrushStyleChooserPage</name>
    <message>
        <source>Plain color</source>
        <translation type="vanished">纯色</translation>
    </message>
</context>
<context>
    <name>NewWordDialog</name>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Enter new word</source>
        <translation>输入新词</translation>
    </message>
</context>
<context>
    <name>PageViewer</name>
    <message>
        <source>Toggle Link to Studio Palette</source>
        <translation type="vanished">切换是否链接到工作室调色板</translation>
    </message>
    <message>
        <source>Remove Reference to Studio Palette</source>
        <translation type="vanished">移除工作室调色板的引用</translation>
    </message>
    <message>
        <source>New Style</source>
        <translation type="vanished">新建样式</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation type="vanished">新建页</translation>
    </message>
    <message>
        <source>- No Styles -</source>
        <translation type="vanished">- 无样式 -</translation>
    </message>
    <message>
        <source>Name Editor</source>
        <translation type="vanished">名字编辑器</translation>
    </message>
</context>
<context>
    <name>PaletteViewer</name>
    <message>
        <source>&amp;Save Palette As</source>
        <translation>另存调色板(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Save Palette</source>
        <translation>保存调色板(&amp;S)</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>选项</translation>
    </message>
    <message>
        <source>&amp;Small Thumbnails View</source>
        <translation>小缩略图视图(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Large Thumbnails View</source>
        <translation>大缩略图视图(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;List View</source>
        <translation>列表视图(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;New Page</source>
        <translation>新建页(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;New Style</source>
        <translation>新建样式(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Move Palette</source>
        <translation>移动调色板(&amp;M)</translation>
    </message>
    <message>
        <source>Color Model: </source>
        <translation type="vanished">色彩模型:</translation>
    </message>
    <message>
        <source>&amp;Palette Gizmo</source>
        <translation>调色板装置(&amp;P)</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>新建页</translation>
    </message>
    <message>
        <source>Delete Page</source>
        <translation>删除页</translation>
    </message>
    <message>
        <source>Palette</source>
        <translation>调色板</translation>
    </message>
    <message>
        <source>Level Palette: </source>
        <translation>层级调色板: </translation>
    </message>
    <message>
        <source>Cleanup Palette</source>
        <translation>清稿调色板</translation>
    </message>
    <message>
        <source>Studio Palette</source>
        <translation>工作室调色板</translation>
    </message>
    <message>
        <source>&amp;Small Thumbnails With Name View</source>
        <translation type="vanished">小缩略图和名称视图(&amp;S)</translation>
    </message>
    <message>
        <source>Lock Palette</source>
        <translation>锁定调色板</translation>
    </message>
    <message>
        <source>&amp;Lock Palette</source>
        <translation>锁定调色板(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Medium Thumbnails View</source>
        <translation>中缩略图视图(&amp;M)</translation>
    </message>
    <message>
        <source>Style Name</source>
        <translation>样式名称</translation>
    </message>
    <message>
        <source>StudioPalette Name</source>
        <translation>工作室调色板名称</translation>
    </message>
    <message>
        <source>Both Names</source>
        <translation>双方名称</translation>
    </message>
    <message>
        <source>Overwrite</source>
        <translation>覆盖</translation>
    </message>
    <message>
        <source>Don&apos;t Overwrite</source>
        <translation>不覆盖</translation>
    </message>
    <message>
        <source>Update</source>
        <translation type="vanished">更新</translation>
    </message>
    <message>
        <source>Don&apos;t Update</source>
        <translation type="vanished">不更新</translation>
    </message>
    <message>
        <source>     (Color Model: </source>
        <translation>     (色彩模型: </translation>
    </message>
    <message>
        <source>)</source>
        <translation>)</translation>
    </message>
    <message>
        <source>Hide New Style Button</source>
        <translation>隐藏新建样式按钮</translation>
    </message>
    <message>
        <source>Show New Style Button</source>
        <translation>显示新建样式按钮</translation>
    </message>
    <message>
        <source>Failed to save palette.</source>
        <translation>保存调色板失败。</translation>
    </message>
    <message>
        <source>Set Toolbar Below Styles</source>
        <translation>使工具条在样式下方</translation>
    </message>
    <message>
        <source>Set Toolbar Above Styles</source>
        <translation>使工具条在样式上方</translation>
    </message>
</context>
<context>
    <name>PaletteViewerGUI::PageViewer</name>
    <message>
        <source>- No Styles -</source>
        <translation>- 无样式 -</translation>
    </message>
    <message>
        <source>Remove Links</source>
        <translation type="vanished">移除链接</translation>
    </message>
    <message>
        <source>New Style</source>
        <translation>新建样式</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>新建页</translation>
    </message>
    <message>
        <source>Name Editor</source>
        <translation>名称编辑器</translation>
    </message>
    <message>
        <source> + </source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PalettesScanPopup</name>
    <message>
        <source>Search for Palettes</source>
        <translation>搜索调色板</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>&lt;files&gt;</source>
        <translation>&lt;文件&gt;</translation>
    </message>
    <message>
        <source>Failed to import palette.</source>
        <translation>导入调色板失败。</translation>
    </message>
</context>
<context>
    <name>ParamViewer</name>
    <message>
        <source>Swatch Viewer</source>
        <translation>样本查看器</translation>
    </message>
</context>
<context>
    <name>ParamsPageSet</name>
    <message>
        <source>Fx Help</source>
        <translation type="vanished">特效帮助</translation>
    </message>
    <message>
        <source>View help page</source>
        <translation>查看帮助页</translation>
    </message>
</context>
<context>
    <name>PegbarPainter</name>
    <message>
        <source>&amp;Reset Center</source>
        <translation>重置中心点(&amp;R)</translation>
    </message>
</context>
<context>
    <name>PlainColorPage</name>
    <message>
        <source>Wheel</source>
        <translation type="vanished">色轮</translation>
    </message>
    <message>
        <source>HSV</source>
        <translation type="vanished">HSV</translation>
    </message>
    <message>
        <source>Alpha</source>
        <translation type="vanished">Alpha</translation>
    </message>
    <message>
        <source>RGB</source>
        <translation type="vanished">RGB</translation>
    </message>
</context>
<context>
    <name>PlaneViewer</name>
    <message>
        <source>Reset View</source>
        <translation>重置视图</translation>
    </message>
    <message>
        <source>Fit To Window</source>
        <translation>适合到窗口</translation>
    </message>
</context>
<context>
    <name>PointParamField</name>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <source>Toonz</source>
        <translation type="vanished">OpenToonz</translation>
    </message>
    <message>
        <source>OpenToonz</source>
        <translation type="vanished">OpenToonz</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Information</source>
        <translation>信息</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>严重警告</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>询问</translation>
    </message>
    <message>
        <source>Styles you are going to delete are used to paint lines and areas in the animation level.
</source>
        <translation>你要删除的样式已经用于绘制动画层级的线和区域。
</translation>
    </message>
    <message>
        <source>How do you want to proceed?</source>
        <translation>要怎么处理？</translation>
    </message>
    <message>
        <source>Delete Styles Only</source>
        <translation>仅删除样式</translation>
    </message>
    <message>
        <source>Delete Styles, Lines and Areas</source>
        <translation>删除样式、线和区域</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Cannot premultiply the selected file.</source>
        <translation>无法对所选文件预乘 Alpha。</translation>
    </message>
    <message>
        <source>Cannot premultiply a vector-based level.</source>
        <translation>无法对矢量层级预乘 Alpha。</translation>
    </message>
    <message>
        <source>Level %1 premultiplied.</source>
        <translation>层级 %1 完成预乘 Alpha。</translation>
    </message>
    <message>
        <source>Frame %1 : conversion failed!</source>
        <translation>帧 %1 : 转换失败！</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">保存</translation>
    </message>
    <message>
        <source>Discard</source>
        <translation type="vanished">放弃更改</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="vanished">是</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="vanished">否</translation>
    </message>
    <message>
        <source>Stage Schematic</source>
        <translation>舞台示意图</translation>
    </message>
    <message>
        <source>FX Schematic</source>
        <translation>特效示意图</translation>
    </message>
    <message>
        <source>Fx Schematic</source>
        <translation type="vanished">特效示意图</translation>
    </message>
    <message>
        <source>Save Motion Path</source>
        <translation>保存运动路径</translation>
    </message>
    <message>
        <source>Motion Path files (*.mpath)</source>
        <translation>运动路径(*.mpath)</translation>
    </message>
    <message>
        <source>Load Motion Path</source>
        <translation>加载运动路径</translation>
    </message>
    <message>
        <source>Can&apos;t paste styles there</source>
        <translation>无法粘贴样式到此</translation>
    </message>
    <message>
        <source>Can&apos;t modify color #0</source>
        <translation>无法修改颜色 #0</translation>
    </message>
    <message>
        <source>There are more cut/copied styles than selected. Paste anyway (adding styles)?</source>
        <translation>剪切/拷贝的样式数量多于所选项。还要继续粘贴(添加样式)吗？</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
    <message>
        <source>Palette</source>
        <translation type="vanished">调色板</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>应用</translation>
    </message>
    <message>
        <source>For further information visit </source>
        <translation type="vanished">更多信息访问</translation>
    </message>
    <message>
        <source>Fullpath:     </source>
        <translation>完整路径:     </translation>
    </message>
    <message>
        <source>File Type:    </source>
        <translation>文件类型:    </translation>
    </message>
    <message>
        <source>Frames:       </source>
        <translation>帧:       </translation>
    </message>
    <message>
        <source>Owner:        </source>
        <translation>所有者:        </translation>
    </message>
    <message>
        <source>Size:         </source>
        <translation>大小:         </translation>
    </message>
    <message>
        <source>Created:      </source>
        <translation>创建时间:      </translation>
    </message>
    <message>
        <source>Modified:     </source>
        <translation>修改时间:     </translation>
    </message>
    <message>
        <source>Last Access:  </source>
        <translation>最近访问时间:  </translation>
    </message>
    <message>
        <source>Image Size:   </source>
        <translation>图像大小:   </translation>
    </message>
    <message>
        <source>SaveBox:      </source>
        <translation>保存框:      </translation>
    </message>
    <message>
        <source>Bits/Sample:  </source>
        <translation>色深:  </translation>
    </message>
    <message>
        <source>Sample/Pixel: </source>
        <translation>通道数量: </translation>
    </message>
    <message>
        <source>Dpi:          </source>
        <translation>DPI:          </translation>
    </message>
    <message>
        <source>Orientation:  </source>
        <translation>方向:  </translation>
    </message>
    <message>
        <source>Compression:  </source>
        <translation>压缩:  </translation>
    </message>
    <message>
        <source>Quality:      </source>
        <translation>画质:      </translation>
    </message>
    <message>
        <source>Smoothing:    </source>
        <translation>平滑:    </translation>
    </message>
    <message>
        <source>Codec:        </source>
        <translation>编码器:        </translation>
    </message>
    <message>
        <source>Alpha Channel:</source>
        <translation>Alpha 通道:</translation>
    </message>
    <message>
        <source>Byte Ordering:</source>
        <translation>字节顺序:</translation>
    </message>
    <message>
        <source>H Pos:</source>
        <translation>水平位置:</translation>
    </message>
    <message>
        <source>Palette Pages:</source>
        <translation>调色板页:</translation>
    </message>
    <message>
        <source>Palette Styles:</source>
        <translation>调色板样式:</translation>
    </message>
    <message>
        <source>Camera Size:      </source>
        <translation>摄影机大小:      </translation>
    </message>
    <message>
        <source>Camera Dpi:       </source>
        <translation>摄影机 DPI:       </translation>
    </message>
    <message>
        <source>Number of Frames: </source>
        <translation>帧数: </translation>
    </message>
    <message>
        <source>Number of Levels: </source>
        <translation>层级数: </translation>
    </message>
    <message>
        <source>Output Path:      </source>
        <translation>输出路径:      </translation>
    </message>
    <message>
        <source>Endianess:      </source>
        <translation>字节次序:      </translation>
    </message>
    <message>
        <source>It is not possible to delete the style #</source>
        <translation>无法删除样式 #</translation>
    </message>
    <message>
        <source>It is not possible to delete styles #0 and #1.</source>
        <translation>无法删除样式 #0 和 #1。</translation>
    </message>
    <message>
        <source>It is not possible to find the %1 level.</source>
        <translation>未能找到层级 %1。</translation>
    </message>
    <message>
        <source>There was an error copying %1</source>
        <translation>拷贝 %1 时发生了错误</translation>
    </message>
    <message>
        <source>It is not possible to find the level %1</source>
        <translation>未能找到层级 %1</translation>
    </message>
    <message>
        <source>Length:       </source>
        <translation>长度:       </translation>
    </message>
    <message>
        <source>Channels: </source>
        <translation>通道: </translation>
    </message>
    <message>
        <source>Sample Rate: </source>
        <translation>采样率: </translation>
    </message>
    <message>
        <source>Sample Size:      </source>
        <translation>采样大小:      </translation>
    </message>
    <message>
        <source>The file %1 does not exist.</source>
        <translation>文件 %1 不存在。</translation>
    </message>
    <message>
        <source>It is not possible to assing a shortcut with modifiers to the visualization commands.</source>
        <translation type="vanished">无法分配带修饰键的快捷键给可视化命令。</translation>
    </message>
    <message>
        <source>It is not possible to save the motion path.</source>
        <translation>无法保存运动路径。</translation>
    </message>
    <message>
        <source>It is not possible to load the motion path.</source>
        <translation>无法加载运动路径。</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation type="vanished">&lt;自定&gt;</translation>
    </message>
    <message>
        <source>Toonz 7.1</source>
        <translation type="vanished">OpenToonz</translation>
    </message>
    <message>
        <source>The file name cannot be empty or contain any of the following characters: (new line) \ / : * ? &quot; |</source>
        <translation>文件名不能为空也不能包含如下的任一字符:
\ / : * ? &quot; |</translation>
    </message>
    <message>
        <source>The source image seems not suitable for this kind of conversion</source>
        <translation>源图像似乎不适合此类转换</translation>
    </message>
    <message>
        <source>Deleting &quot;%1&quot;.
Are you sure?</source>
        <translation>删除 &quot;%1。
你确定吗？</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Paste Style  in Palette : %1</source>
        <translation>粘贴样式到调色板 %1</translation>
    </message>
    <message>
        <source>Delete Style  from Palette : %1</source>
        <translation>从调色板 %1 中删除样式</translation>
    </message>
    <message>
        <source>Cut Style  from Palette : %1</source>
        <translation>从调色板 %1 中剪切样式</translation>
    </message>
    <message>
        <source>  to Palette : %1</source>
        <translation>  到调色板: %1</translation>
    </message>
    <message>
        <source>Paste Color &amp;&amp; Name%1</source>
        <translation>粘贴颜色和名称 %1</translation>
    </message>
    <message>
        <source>Paste Name%1</source>
        <translation>粘贴名称 %1</translation>
    </message>
    <message>
        <source>Paste Color%1</source>
        <translation>粘贴颜色 %1</translation>
    </message>
    <message>
        <source>Paste%1</source>
        <translation>粘贴 %1</translation>
    </message>
    <message>
        <source>Blend Colors  in Palette : %1</source>
        <translation>在调色板 %1 中混合颜色</translation>
    </message>
    <message>
        <source>Toggle Link  in Palette : %1</source>
        <translation>启用/停用链接调色板 %1</translation>
    </message>
    <message>
        <source>Remove Link  in Palette : %1</source>
        <translation type="vanished">移除调色板 %1 的链接</translation>
    </message>
    <message>
        <source>Get Color from Studio Palette</source>
        <translation>从工作室调色板获取样式</translation>
    </message>
    <message>
        <source>Paste Object  </source>
        <translation>粘贴物体</translation>
    </message>
    <message>
        <source>Copy Keyframe</source>
        <translation>拷贝关键帧</translation>
    </message>
    <message>
        <source>Paste Keyframe  at Frame : %1</source>
        <translation>在帧 %1 中粘贴关键帧</translation>
    </message>
    <message>
        <source>Delete Keyframe</source>
        <translation>移除关键帧</translation>
    </message>
    <message>
        <source>Move Keyframe</source>
        <translation>移动关键帧</translation>
    </message>
    <message>
        <source>Change Style   Palette : %1  Style#%2  [R%3 G%4 B%5] -&gt; [R%6 G%7 B%8]</source>
        <translation>更改样式   调色板: %1 样式#%2  [R%3 G%4 B%5] -&gt; [R%6 G%7 B%8]</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="vanished">替换</translation>
    </message>
    <message>
        <source>Modify Fx Param : %1</source>
        <translation>修改特效参数: %1</translation>
    </message>
    <message>
        <source>Modify Fx Param : %1 : %2 -&gt; %3</source>
        <translation>修改特效参数: %1 : %2 -&gt; %3</translation>
    </message>
    <message>
        <source>Modify Fx Param : </source>
        <translation>修改特效参数:</translation>
    </message>
    <message>
        <source>ON : %1</source>
        <translation>启用: %1</translation>
    </message>
    <message>
        <source>OFF : %1</source>
        <translation>关闭: %1</translation>
    </message>
    <message>
        <source>Modify Fx Param : %1 : %2 Key</source>
        <translation>修改特效参数: %1 : 关键帧 %2</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Modify Fx Param : %1 : %2 Point</source>
        <translation>修改特效参数: %1 : %2 点</translation>
    </message>
    <message>
        <source>%1 : Linear ON</source>
        <translation>%1 : 启用线性</translation>
    </message>
    <message>
        <source>%1 : Linear OFF</source>
        <translation>%1 : 关闭线性</translation>
    </message>
    <message>
        <source>Overwrite</source>
        <translation>覆盖</translation>
    </message>
    <message>
        <source>Don&apos;t Overwrite</source>
        <translation>不覆盖</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Deletion of Lines and Areas from raster-based levels is not undoable.
Are you sure?</source>
        <translation>从光栅层级删除线和区域，该操作将无法撤销。
你确定吗？</translation>
    </message>
    <message>
        <source>Modify Fx Param : %1 Key : %2  Frame %3</source>
        <translation>修改特效参数: 关键帧 %1 : %2  帧 %3</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>OpenToonz 1.1</source>
        <translation type="vanished">OpenToonz 1.1</translation>
    </message>
    <message>
        <source>Remove Reference  in Palette : %1</source>
        <translation>移除调色板%1中的引用</translation>
    </message>
    <message>
        <source>It is not possible to assign a shortcut with modifiers to the visualization commands.</source>
        <translation>无法分配带修饰键的快捷键给可视化命令。</translation>
    </message>
    <message>
        <source>Failed to compile m_textureShader.vert.</source>
        <comment>gl</comment>
        <translation>编译 m_textureShader.vert 失败。</translation>
    </message>
    <message>
        <source>Failed to compile m_shader.frag.</source>
        <comment>gl</comment>
        <translation>编译 m_shader.frag 失败。</translation>
    </message>
    <message>
        <source>Failed to add m_shader.vert.</source>
        <comment>gl</comment>
        <translation>添加 m_shader.vert 失败。</translation>
    </message>
    <message>
        <source>Failed to add m_shader.frag.</source>
        <comment>gl</comment>
        <translation>添加 m_shader.frag 失败。</translation>
    </message>
    <message>
        <source>Failed to link simple shader: %1</source>
        <comment>gl</comment>
        <translation>链接 simple shader 失败: %1</translation>
    </message>
    <message>
        <source>Failed to get attribute location of %1</source>
        <comment>gl</comment>
        <translation>获取 : %1 的位置属性失败</translation>
    </message>
    <message>
        <source>Failed to get uniform location of %1</source>
        <comment>gl</comment>
        <translation>获取: %1的统一位置失败</translation>
    </message>
    <message>
        <source>Failed to Open 3DLUT File.</source>
        <translation>打开3DLUT文件失败。</translation>
    </message>
    <message>
        <source>Failed to Load 3DLUT File.
It should start with &quot;3DMESH&quot; keyword.</source>
        <translation>加载 3DLUT 文件失败。
它应该是 3DMESH 关键字开头的。</translation>
    </message>
    <message>
        <source>Failed to Load 3DLUT File.
The second line should be &quot;Mesh [Input bit depth] [Output bit depth]&quot;</source>
        <translation>加载 3DLUT 文件失败。
第二行应该是 &quot;Mesh [Input bit depth] [Output bit depth]&quot;</translation>
    </message>
    <message>
        <source>Failed to Load 3DLUT File.</source>
        <translation>加载 3DLUT 文件失败。</translation>
    </message>
    <message>
        <source>OpenToonz 1.2</source>
        <translation type="vanished">OpenToonz 1.2</translation>
    </message>
    <message>
        <source>Custom Texture</source>
        <comment>TextureStyleChooserPage</comment>
        <translation>定制纹理</translation>
    </message>
    <message>
        <source>Current Frame: </source>
        <translation>当前帧: </translation>
    </message>
    <message>
        <source>File History</source>
        <translation>文件历史</translation>
    </message>
    <message>
        <source>OpenToonz 1.3</source>
        <translation type="obsolete">OpenToonz 1.3</translation>
    </message>
    <message>
        <source>Plain color</source>
        <comment>VectorBrushStyleChooserPage</comment>
        <translation>纯色</translation>
    </message>
    <message>
        <source>Plain color</source>
        <comment>MyPaintBrushStyleChooserPage</comment>
        <translation>纯色</translation>
    </message>
    <message>
        <source>Plain color</source>
        <comment>SpecialStyleChooserPage</comment>
        <translation>纯色</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>That is a reserved file name and cannot be used.</source>
        <translation>被保留的文件名不可使用。</translation>
    </message>
    <message>
        <source>There are no unused styles.</source>
        <translation>没有未使用的样式。</translation>
    </message>
    <message>
        <source>and %1 more styles.</source>
        <translation>和 %1 更多样式。</translation>
    </message>
    <message>
        <source>Erasing unused styles with following indices. Are you sure?

%1</source>
        <translation>擦除未使用的样式时有如下问题。你确认吗？

%1</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>擦除</translation>
    </message>
    <message>
        <source>Click &amp; Drag Palette into Studio Palette</source>
        <translation>点击 &amp; 拖放调色板到工作室调色板</translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
</context>
<context>
    <name>RadioButtonDialog</name>
    <message>
        <source>Toonz</source>
        <translation type="vanished">Toonz</translation>
    </message>
    <message>
        <source>OpenToonz</source>
        <translation type="vanished">OpenToonz</translation>
    </message>
</context>
<context>
    <name>RgbLinkButtons</name>
    <message>
        <source>Copy RGB : %1 &gt; %2</source>
        <translation>拷贝RGB : %1 &gt; %2</translation>
    </message>
    <message>
        <source>Swap %1 and %2</source>
        <translation>互换%1 和 %2</translation>
    </message>
</context>
<context>
    <name>SchematicName</name>
    <message>
        <source>Cu&amp;t</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">删除(&amp;D)</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SchematicViewer</name>
    <message>
        <source>&amp;Fit to Window</source>
        <translation>适合窗口(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Focus on Current</source>
        <translation>对焦到当前物体(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Reorder Nodes</source>
        <translation>重新排列节点(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Reset Size</source>
        <translation>重置大小(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Minimize Nodes</source>
        <translation>最小化节点(&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Maximize Nodes</source>
        <translation>最大化节点(&amp;M)</translation>
    </message>
    <message>
        <source>&amp;New Pegbar</source>
        <translation>新建定位尺(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;New Camera</source>
        <translation>新建摄影机(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;New Motion Path</source>
        <translation>新建运动路径(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Schematic Toggle</source>
        <translation type="vanished">切换示意图(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Swtich output port display mode</source>
        <translation type="vanished">切换输出端口显示模式(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Toggle node icons</source>
        <translation>显示/隐藏节点图标(&amp;T)</translation>
    </message>
    <message>
        <source>&amp;Selection Mode</source>
        <translation>选择模式(&amp;S0</translation>
    </message>
    <message>
        <source>&amp;Zoom Mode</source>
        <translation>缩放模式(&amp;Z）</translation>
    </message>
    <message>
        <source>&amp;Hand Mode</source>
        <translation>抓手模式(&amp;H)</translation>
    </message>
    <message>
        <source>&amp;Switch output port display mode</source>
        <translation>切换输出端口显示模式(&amp;S)</translation>
    </message>
</context>
<context>
    <name>SchematicWindowEditor</name>
    <message>
        <source>&amp;Close Editor</source>
        <translation>关闭编辑器(&amp;C)</translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <source>Reset to default</source>
        <translation type="vanished">重新初始化</translation>
    </message>
</context>
<context>
    <name>SimilarShapeSegmentPage</name>
    <message>
        <source>Reference Curve:</source>
        <translation>参考曲线:</translation>
    </message>
    <message>
        <source>Frame Offset:</source>
        <translation>帧偏移:</translation>
    </message>
    <message>
        <source>There is a syntax error in the definition of the interpolation.</source>
        <translation>插值定义中有个语法错误。</translation>
    </message>
    <message>
        <source>There is a circular reference in the definition of the interpolation.</source>
        <translation>插值定义中有个循环引用。</translation>
    </message>
</context>
<context>
    <name>SpecialStyleChooserPage</name>
    <message>
        <source>Plain color</source>
        <translation type="vanished">纯色</translation>
    </message>
</context>
<context>
    <name>SpeedInOutSegmentPage</name>
    <message>
        <source>Speed in:</source>
        <translation type="vanished">速入:</translation>
    </message>
    <message>
        <source>Speed out:</source>
        <translation type="vanished">速出:</translation>
    </message>
    <message>
        <source>First Speed:</source>
        <translation>起点速度:</translation>
    </message>
    <message>
        <source>Handle:</source>
        <translation>手柄:</translation>
    </message>
    <message>
        <source>/</source>
        <translation>/</translation>
    </message>
    <message>
        <source>Last Speed:</source>
        <translation>终点速度:</translation>
    </message>
    <message>
        <source>---</source>
        <translation>---</translation>
    </message>
</context>
<context>
    <name>SplinePainter</name>
    <message>
        <source>&amp;Delete</source>
        <translation>删除(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Save Motion Path...</source>
        <translation>保存运动路径(&amp;S)...</translation>
    </message>
    <message>
        <source>&amp;Load Motion Path...</source>
        <translation>加载运动路径(&amp;L)...</translation>
    </message>
</context>
<context>
    <name>StageSchematicNode</name>
    <message>
        <source>Toggle Autorotate Along Motion Path</source>
        <translation>启用/停止追随移动路径自动旋转</translation>
    </message>
    <message>
        <source>Toggle Link Motion Path to Control Points</source>
        <translation>启用/停止链接移动路径到控制点</translation>
    </message>
</context>
<context>
    <name>StageSchematicScene</name>
    <message>
        <source>&amp;New Pegbar</source>
        <translation>新建定位尺(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;New Motion Path</source>
        <translation>新建运动路径(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;New Camera</source>
        <translation>新建摄影机(&amp;N)</translation>
    </message>
</context>
<context>
    <name>StudioPaletteTreeViewer</name>
    <message>
        <source>This folder is not empty. Delete anyway?</source>
        <translation>此文件夹不是空的。一定要删除吗？</translation>
    </message>
    <message>
        <source>New Palette</source>
        <translation>新建调色板</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>新建文件夹</translation>
    </message>
    <message>
        <source>Delete Folder</source>
        <translation>删除文件夹</translation>
    </message>
    <message>
        <source>Load into Current Palette</source>
        <translation>加载到当前调色板</translation>
    </message>
    <message>
        <source>Merge to Current Palette</source>
        <translation>合并到当前调色板</translation>
    </message>
    <message>
        <source>Replace with Current Palette</source>
        <translation>用当前调色板替换</translation>
    </message>
    <message>
        <source>Delete Palette</source>
        <translation>删除调色板</translation>
    </message>
    <message>
        <source>Search for Palettes</source>
        <translation>搜索调色板</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Adjust Current Level to This Palette</source>
        <translation>调整当前层级到此调色板</translation>
    </message>
    <message>
        <source>Convert to Studio Palette and Overwrite</source>
        <translation>转换为工作室调色板并覆盖</translation>
    </message>
    <message>
        <source>the palette &quot;%1&quot;</source>
        <translation>调色板 &quot;%1&quot;</translation>
    </message>
    <message>
        <source>the selected palettes</source>
        <translation>所选的调色板</translation>
    </message>
    <message>
        <source>Move %1 to &quot;%2&quot;. Are you sure ?</source>
        <translation>移动  %1 到 &quot;%2&quot;。你确定吗？</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>移动</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>The current palette %1
in the studio palette has been modified. Do you want to save your changes?</source>
        <translation>当前调色板 %1
在工作室调色板中已经被修改了。你要保存所做的改动吗？</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Discard</source>
        <translation>放弃更改</translation>
    </message>
    <message>
        <source>Convert %1 to Studio Palette and Overwrite. 
Are you sure ?</source>
        <translation>转换 %1 到工作室调色板并覆盖。
你确定要这样做吗？</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="obsolete">是</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="obsolete">否</translation>
    </message>
    <message>
        <source>Replacing all selected palettes with the palette &quot;%1&quot;. 
Are you sure ?</source>
        <translation>用调色板 &quot;%1&quot; 替换所有被选中的调色版。
你确定要这样做吗？</translation>
    </message>
    <message>
        <source>Replacing the palette &quot;%1&quot; with the palette &quot;%2&quot;. 
Are you sure ?</source>
        <translation>用调色板 &quot;%2&quot; 替换调色板 &quot;%1&quot;。
你确定要这样做吗？</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>替换</translation>
    </message>
    <message>
        <source>Convert</source>
        <translation>转换</translation>
    </message>
    <message>
        <source>Failed to save palette.</source>
        <translation>保存调色板失败。</translation>
    </message>
</context>
<context>
    <name>StudioPaletteViewer</name>
    <message>
        <source>&amp;New Folder</source>
        <translation type="vanished">新建文件夹(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;New Palette</source>
        <translation type="vanished">新建调色板(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Search for Palettes</source>
        <translation type="vanished">搜索调色板(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="vanished">删除(&amp;D)</translation>
    </message>
</context>
<context>
    <name>StyleEditor</name>
    <message>
        <source>Apply</source>
        <translation>应用</translation>
    </message>
    <message>
        <source>Apply changes to current style</source>
        <translation>应用更改到当前样式</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自动</translation>
    </message>
    <message>
        <source>Automatically update style changes</source>
        <translation>自动更新样式的更改</translation>
    </message>
    <message>
        <source>Return To Previous Style</source>
        <translation>返回前一样式</translation>
    </message>
    <message>
        <source>Current Style</source>
        <translation>当前样式</translation>
    </message>
    <message>
        <source>Plain</source>
        <translation type="vanished">纯色</translation>
    </message>
    <message>
        <source>Texture</source>
        <translation>纹理</translation>
    </message>
    <message>
        <source>Special</source>
        <translation type="vanished">特殊</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation type="vanished">自定</translation>
    </message>
    <message>
        <source>Vector Brush</source>
        <translation>矢量笔刷</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Auto
Apply</source>
        <translation type="vanished">自动
应用</translation>
    </message>
    <message>
        <source>MyPaint Brush</source>
        <translation type="vanished">MyPaint 笔刷</translation>
    </message>
    <message>
        <source>Auto  
Apply</source>
        <translation type="vanished">自动
应用</translation>
    </message>
    <message>
        <source>- Style not Selected -</source>
        <translation type="vanished">- 无样式被选中 -</translation>
    </message>
    <message>
        <source>[CLEANUP]  </source>
        <translation type="vanished">[清稿]  </translation>
    </message>
    <message>
        <source>[STUDIO]  </source>
        <translation type="vanished">[工作室]  </translation>
    </message>
    <message>
        <source>[LEVEL]  </source>
        <translation type="vanished">[层级]  </translation>
    </message>
    <message>
        <source>- Style is Not Valid -</source>
        <translation type="vanished">- 无效的样式 -</translation>
    </message>
    <message>
        <source>Generated</source>
        <translation>已生成的</translation>
    </message>
    <message>
        <source>Trail</source>
        <translation>轨迹</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>颜色</translation>
    </message>
    <message>
        <source>Vector</source>
        <translation>矢量</translation>
    </message>
    <message>
        <source>Raster</source>
        <translation>光栅</translation>
    </message>
    <message>
        <source>Show or hide parts of the Color Page.</source>
        <translation>显示或隐藏部分颜色页。</translation>
    </message>
    <message>
        <source>Toggle orientation of the Color Page.</source>
        <translation type="vanished">打开/关闭颜色页的朝向。</translation>
    </message>
    <message>
        <source>No Style Selected</source>
        <translation>无样式被选中</translation>
    </message>
    <message>
        <source>Style Editor - No Valid Style Selected</source>
        <translation>样式编辑器 - 无有效样式被选中</translation>
    </message>
    <message>
        <source>Wheel</source>
        <translation>色轮</translation>
    </message>
    <message>
        <source>HSV</source>
        <translation>HSV</translation>
    </message>
    <message>
        <source>Alpha</source>
        <translation>透明度</translation>
    </message>
    <message>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <source>Palette</source>
        <translation>调色板</translation>
    </message>
    <message>
        <source>Cleanup </source>
        <translation>清理 </translation>
    </message>
    <message>
        <source>Studio </source>
        <translation>工作室 </translation>
    </message>
    <message>
        <source>Level </source>
        <translation>层级 </translation>
    </message>
    <message>
        <source>Hex</source>
        <translation>16进制</translation>
    </message>
    <message>
        <source>Relative colored + Triangle handle</source>
        <translation>相对色+三角手柄</translation>
    </message>
    <message>
        <source>Absolute colored + Line handle</source>
        <translation>绝对色+线条手柄</translation>
    </message>
    <message>
        <source>Slider Appearance</source>
        <translation>滑动器外观</translation>
    </message>
    <message>
        <source>Toggle Orientation</source>
        <translation>切换适应方向</translation>
    </message>
    <message>
        <source>Hex Color Names...</source>
        <translation>16进制颜色名...</translation>
    </message>
</context>
<context>
    <name>StyleEditorGUI::ColorChannelControl</name>
    <message>
        <source>R</source>
        <translation></translation>
    </message>
    <message>
        <source>G</source>
        <translation></translation>
    </message>
    <message>
        <source>B</source>
        <translation></translation>
    </message>
    <message>
        <source>A</source>
        <translation></translation>
    </message>
    <message>
        <source>H</source>
        <translation></translation>
    </message>
    <message>
        <source>S</source>
        <translation></translation>
    </message>
    <message>
        <source>V</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>StyleEditorGUI::PlainColorPage</name>
    <message>
        <source>Wheel</source>
        <translation type="vanished">色轮</translation>
    </message>
    <message>
        <source>HSV</source>
        <translation type="vanished">HSV</translation>
    </message>
    <message>
        <source>Matte</source>
        <translation type="vanished">不透明度</translation>
    </message>
    <message>
        <source>RGB</source>
        <translation type="vanished">RGB</translation>
    </message>
    <message>
        <source>Alpha</source>
        <translation type="vanished">透明度</translation>
    </message>
</context>
<context>
    <name>StyleEditorGUI::SettingsPage</name>
    <message>
        <source>Autopaint for Lines</source>
        <translation>线自动上色</translation>
    </message>
    <message>
        <source>Reset to default</source>
        <translation>重新初始化</translation>
    </message>
</context>
<context>
    <name>StyleNameEditor</name>
    <message>
        <source>Name Editor</source>
        <translation>名称编辑器</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="vanished">应用</translation>
    </message>
    <message>
        <source>Style Name</source>
        <translation>样式名称</translation>
    </message>
    <message>
        <source>Name Editor: # %1</source>
        <translation>名称编辑器: # %1</translation>
    </message>
    <message>
        <source>Apply and Next</source>
        <translation>应用并转到下一个</translation>
    </message>
    <message>
        <source>Easy Inputs</source>
        <translation>简易输入</translation>
    </message>
</context>
<context>
    <name>SwatchViewer</name>
    <message>
        <source>Reset View</source>
        <translation>重置视图</translation>
    </message>
    <message>
        <source>Fit To Window</source>
        <translation>适合窗口</translation>
    </message>
</context>
<context>
    <name>TMessageViewer</name>
    <message>
        <source>Errors</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Warnings</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>Infos</source>
        <translation type="vanished">信息</translation>
    </message>
    <message>
        <source> Clear </source>
        <translation> 清除 </translation>
    </message>
    <message>
        <source>Display:  </source>
        <translation>显示:  </translation>
    </message>
    <message>
        <source>Info</source>
        <translation>信息</translation>
    </message>
</context>
<context>
    <name>TablePainter</name>
    <message>
        <source>&amp;Reset Center</source>
        <translation>重置中心点(&amp;R)</translation>
    </message>
    <message>
        <source>Table</source>
        <translation>动画台</translation>
    </message>
</context>
<context>
    <name>ToneCurveField</name>
    <message>
        <source>Channel:</source>
        <translation type="vanished">通道:</translation>
    </message>
</context>
<context>
    <name>VectorBrushStyleChooserPage</name>
    <message>
        <source>Plain color</source>
        <translation type="vanished">纯色</translation>
    </message>
</context>
<context>
    <name>WordButton</name>
    <message>
        <source>Remove %1</source>
        <translation>删除 %1</translation>
    </message>
</context>
</TS>
